@@ -7,9 +7,11 @@ from eppy3000.experimental import listfields
 from eppy3000.modelmaker import EPJ
 
 
-@pytest.mark.parametrize('surfobjecttxt, expected', [
-    (
-"""{ "BuildingSurface:Detailed": {
+@pytest.mark.parametrize(
+    "surfobjecttxt, expected",
+    [
+        (
+            """{ "BuildingSurface:Detailed": {
         "BACK-1": {
             "construction_name": "WALL-1",
             "idf_max_extensible_fields": 12,
@@ -36,15 +38,15 @@ from eppy3000.modelmaker import EPJ
             "zone_name": "SPACE3-1"
         }
 }
-}"""
-,
-    [(30.5, 15.2, 2.4), (1, 2, 3)]
-    ), # surfobjecttxt, expected
-])
+}""",
+            [(30.5, 15.2, 2.4), (1, 2, 3)],
+        ),  # surfobjecttxt, expected
+    ],
+)
 def test_surf2list(surfobjecttxt, expected):
     """py.test for surf2list"""
     epj = EPJ(StringIO(surfobjecttxt))
-    surfs = epj.epobjects['BuildingSurface:Detailed']
+    surfs = epj.epobjects["BuildingSurface:Detailed"]
     surfobject = surfs[0]
     result = listfields.surf2list(surfobject)
-    assert result == expected
\ No newline at end of file
+    assert result == expected
